# Build configuration

# set to '1' to do a bootstrap build
# thus disabling examples and docs as they needs pkg itself to build
%define bootstrap 0

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%if %bootstrap
%define build_docs 0
%else
%define build_docs 1
%endif
%endif

%if %bootstrap
%bcond_with examples
%else
%bcond_without examples
%endif

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qt5compat-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libcore5compat   %mklibname qt%{qtmajor}core5compat %{qtmajor}
%define libcore5compat_d %mklibname qt%{qtmajor}core5compat -d

Name:           qt5compat6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt 5.x compatibility library for Qt %{qtmajor}
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}
BuildRequires:  cmake(Qt6Xml) >= %{version}
%if %{with examples}
BuildRequires:  cmake(Qt6Core5Compat)
%endif
BuildRequires:  pkgconfig(icu-uc)

Provides:       qt%{qtmajor}-qt5compat = %{version}-%{release}

%description
Qt 5.x compatibility library for Qt %{qtmajor}.

%files
%license LICENSES/*
%dir %{_qt6_qmldir}/Qt5Compat/
%{_qt6_qmldir}/Qt5Compat/GraphicalEffects/
%{_qt6_archdatadir}/sbom/qt5compat-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtCore5Compat%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtCore5Compat%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtcore5compat.qch
%{_qt6_docdir}/qtcore5compat/
%{_qt6_docdir}/qtgraphicaleffects5compat.qch
%{_qt6_docdir}/qtgraphicaleffects5compat/
%endif

#------------------------------------------------------------------------------

%package -n     %{libcore5compat}
Summary:        Qt 5.x compatibility library for Qt %{qtmajor}
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libcore5compat}
Qt 5.x compatibility library for Qt %{qtmajor}.

%files -n %{libcore5compat}
%license LICENSES/*
%{_qt6_libdir}/libQt6Core5Compat.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libcore5compat_d}
Summary:        Devel files needed to build apps based on QtCore5Compat
Group:          Development/KDE and Qt
Requires:       %{libcore5compat} = %{version}
Provides:       libqt6core5compat-devel = %{version}
Provides:       libqtcore5compat6-devel = %{version}
Provides:       qt6core5compat-devel = %{version}
Provides:       qtcore5compat6-devel = %{version}
Provides:       qt%{qtmajor}-qt5compat-devel = %{version}-%{release}

%description -n %{libcore5compat_d}
Devel files needed to build apps based on the Qt 5.x compatibility
library for Qt %{qtmajor}.

%files -n %{libcore5compat_d}
%{_qt6_includedir}/QtCore5Compat/
%{_qt6_libdir}/libQt6Core5Compat.so
%{_qt6_libdir}/libQt6Core5Compat.prl
%{_qt6_libdir}/cmake/Qt6Core5Compat/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_core5compat.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_core5compat_private.pri
%{_qt6_libdir}/qt6/modules/Core5Compat.json
%{_qt6_libdir}/qt6/metatypes/qt6core5compat_relwithdebinfo_metatypes.json
%{_qt6_libdir}/pkgconfig/Qt6Core5Compat.pc
%if %{with examples}
%{_qt6_examplesdir}/core5/
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/*.cmake
%{_qt6_libdir}/cmake/Qt6/FindWrapIconv.cmake
#
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qt5compat-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 6.8.3-2.mga10
+ Revision: 2250000
- Mageia 10 Mass Rebuild

* Wed Mar 26 2025 daviddavid <daviddavid> 6.8.3-1.mga10
+ Revision: 2170102
- New version 6.8.3

* Sun Jan 12 2025 wally <wally> 6.8.1-2.mga10
+ Revision: 2138445
- rebuild for icu 76.1

* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2125918
- New version 6.8.1

* Sun Oct 06 2024 daviddavid <daviddavid> 6.7.3-2.mga10
+ Revision: 2103754
- non bootstrap build
- enable docs building

* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103602
- New version 6.7.3

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083098
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072545
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Thu May 23 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2066224
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041612
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999026
- New version 6.6.0

* Tue Oct 10 2023 daviddavid <daviddavid> 6.5.2-3.mga10
+ Revision: 1994269
- bootstrap build
- rebuild for icu73
- non-bootstrap build

* Mon Sep 11 2023 neoclust <neoclust> 6.5.2-1.mga10
+ Revision: 1986118
- New version 6.5.2

* Sun Jan 08 2023 daviddavid <daviddavid> 6.4.1-3.mga9
+ Revision: 1931365
- build examples
+ squidf <squidf>
- Mass rebuild for icu 72.1

* Thu Dec 15 2022 neoclust <neoclust> 6.4.1-1.mga9
+ Revision: 1923036
- New version 6.4.1

* Tue Oct 04 2022 neoclust <neoclust> 6.4.0-1.mga9
+ Revision: 1894783
- New version 6.4.0

* Wed Sep 14 2022 wally <wally> 6.3.1-2.mga9
+ Revision: 1888224
- pkg Qt5Compat.GraphicalEffects
+ neoclust <neoclust>
- New version 6.3.1

* Fri Jul 29 2022 squidf <squidf> 6.3.0-1.mga9
+ Revision: 1872831
- rebuild for icu 71.1
+ neoclust <neoclust>
- New version 6.3.0

* Tue Apr 05 2022 umeabot <umeabot> 6.2.3-2.mga9
+ Revision: 1844652
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 neoclust <neoclust> 6.2.3-1.mga9
+ Revision: 1781907
- New version 6.2.3

* Sun Nov 14 2021 neoclust <neoclust> 6.2.1-1.mga9
+ Revision: 1756244
- New version 6.2.1

* Fri Nov 12 2021 neoclust <neoclust> 6.2.0-1.mga9
+ Revision: 1755997
- New version 6.2.0

* Sat May 15 2021 daviddavid <daviddavid> 6.1.0-1.mga9
+ Revision: 1723674
- initial package qt5compat6

